"""Physics system.

This module provides the PhysicsManager class, which handles collision detection
and resolution.
"""

from pedre.systems.physics.manager import PhysicsManager

__all__ = ["PhysicsManager"]
