"""Player management system.

This module provides the PlayerManager class, which handles player spawning,
movement, and animation.
"""

from pedre.systems.player.manager import PlayerManager

__all__ = ["PlayerManager"]
